@@ -10,7 +10,7 @@ use DBI;
 use Data::PowerSet;
 use IO::File;
 
-our $VERSION = '0.0301';
+our $VERSION = '0.04';
 
 
 
@@ -189,6 +189,25 @@ sub power {
 
 
 sub score {
+    my $self = shift;
+    my ( $open_sparator, $close_separator ) = @_;
+
+    my $parts = $self->score_parts( $open_sparator, $close_separator );
+
+    for my $mask ( keys %$parts ) {
+        for my $element ( @{ $parts->{$mask} } ) {
+            my $key  = "$element->{score}{knowns}:$element->{score}{unknowns} chunks / $element->{score}{knownc}:$element->{score}{unknownc} chars";
+            my $val  = join ', ', @{ $element->{partition} };
+            my $defn = join ', ', @{ $element->{definition} };
+            push @{ $self->{score}{$mask} }, { score => $key, partition => $val, definition => $defn };
+        }
+    }
+
+    return $self->{score};
+}
+
+
+sub score_parts {
     my $self = shift;
     my ( $open_sparator, $close_separator, $line_terminator ) = @_;
 
@@ -207,12 +226,11 @@ sub score {
             knownc   => 0,
             unknownc => 0,
         );
-        my $val = '';
+
         for my $x ( reverse sort @$c ) {
             # Run-length encode an "un-digitized" string.
             my $y = _rle($x);
             my ( $knowns, $unknowns, $knownc, $unknownc ) = _grouping($y);
-#            $val .= "$x ($y)[$knowns/$unknowns | $knownc/$unknownc] ";
             # Accumulate the counters!
             $count{knowns}   += $knowns;
             $count{unknowns} += $unknowns;
@@ -221,27 +239,21 @@ sub score {
         }
 
         my ( $s, $m ) = _reconstruct( $self->{word}, $c, $open_sparator, $close_separator );
-#        $val .= "$count{knowns}:$count{unknowns} chunks / $count{knownc}:$count{unknownc} chars => "
-#          . join( ', ', @$s );
-#        warn "V:$val\n";
 
-        my $key = "$count{knowns}:$count{unknowns} chunks / $count{knownc}:$count{unknownc} chars";
-        $val = join ", $line_terminator", @$s;
-
-        # TODO Re-model the knowns!!
-        my $defn = '';
+        my $defn = [];
         for my $i ( @$m )
         {
             for my $j ( keys %{ $self->{known} } )
             {
-                $defn .= $self->{known}{$j}{defn} . ". $line_terminator" if $self->{known}{$j}{mask} eq $i;
+                push @$defn, $self->{known}{$j}{defn} if $self->{known}{$j}{mask} eq $i;
             }
         }
 
-        push @{ $self->{score}{$together} }, { score => $key, partition => $val, definition => $defn };
+        push @{ $self->{score_parts}{$together} },
+            { score => \%count, partition => $s, definition => $defn };
     }
 
-    return $self->{score};
+    return $self->{score_parts};
 }
 
 sub _grouping {
@@ -360,7 +372,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.0301
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -380,6 +392,7 @@ version 0.0301
 
  my ($known) = $p->knowns;
  my $combos  = $p->power;
+ my $parts   = $p->score_parts;
  my $scored  = $p->score;
 
  # The best guess is the last sorted score-set:
@@ -436,11 +449,21 @@ Find the "non-overlapping powerset."
 
   $score = $p->score( $open_sparator, $close_separator, $line_terminator );
 
+Score the known vs unknown word part combinations into ratios of characters and
+chunks or parts or "spans of adjacent characters" B<as a collection of strings>.
+
+If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
+default.
+
+=head2 score_parts()
+
+  $score = $p->score_parts( $open_sparator, $close_separator );
+
 Score the known vs unknown word part combinations into ratios of characters and
 chunks or parts or "spans of adjacent characters."
 
-If not given, the B<$open_sparator>, B<$close_separator> and B<$line_terminator>
-are '<', '>' and '', by default, respectively.
+If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
+default.
 
 =head1 SEE ALSO
 
